@@ -3,9 +3,10 @@ Base classes for Covasim.
 '''
 
 import datetime as dt
-import numpy as np # Needed for a few things not provided by pl
-import sciris as sc
+import numpy as np
+import pylab as pl
 import pandas as pd
+import sciris as sc
 from . import utils as cvu
 from . import misc as cvm
 from . import defaults as cvd
@@ -32,8 +33,8 @@ class ParsObj(sc.prettyobj):
         except:
             all_keys = '\n'.join(list(self.pars.keys()))
             errormsg = f'Key "{key}" not found; available keys:\n{all_keys}'
-            raise cvm.KeyNotFoundError(errormsg)
-            return
+            raise sc.KeyNotFoundError(errormsg)
+        return
 
     def __setitem__(self, key, value):
         ''' Ditto '''
@@ -42,7 +43,7 @@ class ParsObj(sc.prettyobj):
         else:
             all_keys = '\n'.join(list(self.pars.keys()))
             errormsg = f'Key "{key}" not found; available keys:\n{all_keys}'
-            raise cvm.KeyNotFoundError(errormsg)
+            raise sc.KeyNotFoundError(errormsg)
         return
 
     def update_pars(self, pars=None, create=False):
@@ -63,7 +64,7 @@ class ParsObj(sc.prettyobj):
                 mismatches = [key for key in pars.keys() if key not in available_keys]
                 if len(mismatches):
                     errormsg = f'Key(s) {mismatches} not found; available keys are {available_keys}'
-                    raise cvm.KeyNotFoundError(errormsg)
+                    raise sc.KeyNotFoundError(errormsg)
             self.pars.update(pars)
         return
 
@@ -186,19 +187,83 @@ class BaseSim(ParsObj):
             return np.array([])
 
 
-    def inds2dates(self, inds, dateformat=None):
-        ''' Convert a set of indices to a set of dates '''
+    def day(self, day, *args):
+        '''
+        Convert a string, date/datetime object, or int to a day (int).
 
-        if sc.isnumber(inds): # If it's a number, convert it to a list
-            inds = sc.promotetolist(inds)
+        Args:
+            day (str, date, int, or list): convert any of these objects to a day relative to the simulation's start day
+
+        Returns:
+            days (int or str): the day(s) in simulation time
+
+        **Example**::
+
+            sim.day('2020-04-05') # Returns 35
+        '''
+        # Do not process a day if it's not supplied
+        if day is None:
+            return None
+
+        # Convert to list
+        if sc.isstring(day) or sc.isnumber(day) or isinstance(day, (dt.date, dt.datetime)):
+            day = sc.promotetolist(day) # Ensure it's iterable
+        day.extend(args)
+
+        days = []
+        for d in day:
+            if sc.isnumber(d):
+                days.append(int(d)) # Just convert to an integer
+            else:
+                try:
+                    if sc.isstring(d):
+                        d = sc.readdate(d).date()
+                    elif isinstance(d, dt.datetime):
+                        d = d.date()
+                    d_day = (d - self['start_day']).days
+                    days.append(d_day)
+                except Exception as E:
+                    errormsg = f'Could not interpret "{d}" as a date: {str(E)}'
+                    raise ValueError(errormsg)
+
+        # Return an integer rather than a list if only one provided
+        if len(days)==1:
+            days = days[0]
+
+        return days
+
+
+    def date(self, ind, *args, dateformat=None):
+        '''
+        Convert an integer or list of integer simulation days to a date/list of dates.
+
+        Args:
+            ind (int, list, or array): the day(s) in simulation time
+
+        Returns:
+            dates (str or list): the date relative to the simulation start day, as an integer
+
+        **Example**::
+
+            sim.date(35) # Returns '2020-04-05'
+        '''
+
+        if sc.isnumber(ind): # If it's a number, convert it to a list
+            ind = sc.promotetolist(ind)
+        ind.extend(args)
 
         if dateformat is None:
-            dateformat = '%b-%d'
+            dateformat = '%Y-%m-%d'
 
         dates = []
-        for ind in inds:
-            tmp = self['start_day'] + dt.timedelta(days=int(ind))
+        for i in ind:
+            tmp = self['start_day'] + dt.timedelta(days=int(i))
             dates.append(tmp.strftime(dateformat))
+
+        # Return a string rather than a list if only one provided
+        if len(ind)==1:
+            dates = dates[0]
+
         return dates
 
 
@@ -287,7 +352,8 @@ class BaseSim(ParsObj):
             A unicode string containing a JSON representation of the results,
             or writes the JSON file to disk
 
-        Examples:
+        **Examples**::
+
             json = sim.to_json()
             sim.to_json('results.json')
             sim.to_json('summary.json', keys='summary')
@@ -717,7 +783,7 @@ class BasePeople(sc.prettyobj):
             n = len(new_layer['p1'])
             if 'beta' not in new_layer or len(new_layer['beta']) != n:
                 if beta is None:
-                    beta = self.pars['beta_layer'][lkey]
+                    beta = 1.0
                 beta = cvd.default_float(beta)
                 new_layer['beta'] = np.ones(n, dtype=cvd.default_float)*beta
 
@@ -751,7 +817,7 @@ class BasePeople(sc.prettyobj):
         except KeyError:
             lkeystr = ', '.join(lkeys)
             errormsg = f'Layer "{lkey}" could not be loaded since it was not among parameter keys "{lkeystr}". Please update manually or via sim.reset_layer_pars().'
-            raise cvm.KeyNotFoundError(errormsg)
+            raise sc.KeyNotFoundError(errormsg)
 
         # Turn into a dataframe
         for lkey in lkeys:
@@ -992,4 +1058,43 @@ class TransTree(sc.prettyobj):
 
 
     def plot(self):
-        raise NotImplementedError('Transmission tree plotting is not yet available')
\ No newline at end of file
+        ''' Plot the transmission tree '''
+        if self.detailed is None:
+            errormsg = 'Please run sim.people.make_detailed_transtree() before calling plotting'
+            raise ValueError(errormsg)
+
+        detailed = filter(None, self.detailed)
+
+        df = pd.DataFrame(detailed).rename(columns={'date': 'Day'})
+        df = df.loc[df['layer'] != 'seed_infection']
+
+        df['Stage'] = 'Symptomatic'
+        df.loc[df['s_asymp'], 'Stage'] = 'Asymptomatic'
+        df.loc[df['s_presymp'], 'Stage'] = 'Presymptomatic'
+
+        df['Severity'] = 'Mild'
+        df.loc[df['s_sev'], 'Severity'] = 'Severe'
+        df.loc[df['s_crit'], 'Severity'] = 'Critical'
+
+        fig = pl.figure(figsize=(16,10))
+        i=1; r=2; c=3
+
+        def plot(key, title, i):
+            dat = df.groupby(['Day', key]).size().unstack(key)
+            ax = pl.subplot(r,c,i);
+            dat.plot(ax=ax, legend=None)
+            pl.legend(title=None)
+            ax.set_title(title)
+
+        to_plot = {
+            'layer':'Layer',
+            'Stage':'Source stage',
+            's_diag':'Source diagnosed',
+            's_quar':'Source quarantined',
+            't_quar':'Target quarantined',
+            'Severity':'Symptomatic source severity'
+        }
+        for i, (key, title) in enumerate(to_plot.items()):
+            plot(key, title, i+1)
+
+        return fig
