@@ -70,10 +70,10 @@ class People(cvb.BasePeople):
         prognoses = pars['prognoses']
         age_cutoffs = prognoses['age_cutoffs']
         inds = np.fromiter((find_cutoff(age_cutoffs, this_age) for this_age in self.age), dtype=cvd.default_int, count=len(self))
-        self.symp_prob[:]   = pars['rel_symp_prob']   * prognoses['symp_probs'][inds]
-        self.severe_prob[:] = pars['rel_severe_prob'] * prognoses['severe_probs'][inds]
-        self.crit_prob[:]   = pars['rel_crit_prob']   * prognoses['crit_probs'][inds]
-        self.death_prob[:]  = pars['rel_death_prob']  * prognoses['death_probs'][inds]
+        self.symp_prob[:]   = prognoses['symp_probs'][inds]
+        self.severe_prob[:] = prognoses['severe_probs'][inds]
+        self.crit_prob[:]   = prognoses['crit_probs'][inds]
+        self.death_prob[:]  = prognoses['death_probs'][inds]
         self.rel_sus[:]     = 1.0 # By default: is susceptible
         self.rel_trans[:]   = 0.0 # By default: cannot transmit
 
@@ -136,19 +136,10 @@ class People(cvb.BasePeople):
         return self.contacts
 
 
-    def make_susceptible(self, inds):
-        '''
-        Make person susceptible. This is used during dynamic resampling
-        '''
-        for key in self.meta.states:
-            if key == 'susceptible':
-                self[key][inds] = True
-            else:
-                self[key][inds] = False
-
-        for key in self.meta.dates + self.meta.durs:
-            self[key][inds] = np.nan
 
+    def make_detailed_transtree(self):
+        ''' Convenience function to avoid repeating the people object '''
+        self.transtree.make_detailed(self)
         return
 
 
@@ -254,6 +245,22 @@ class People(cvb.BasePeople):
 
     #%% Methods to make events occur (infection and diagnosis)
 
+    def make_susceptible(self, inds):
+        '''
+        Make person susceptible. This is used during dynamic resampling
+        '''
+        for key in self.meta.states:
+            if key == 'susceptible':
+                self[key][inds] = True
+            else:
+                self[key][inds] = False
+
+        for key in self.meta.dates + self.meta.durs:
+            self[key][inds] = np.nan
+
+        return
+
+
     def infect(self, inds, bed_max=None, verbose=True):
         '''
         Infect people and determine their eventual outcomes.
@@ -272,24 +279,23 @@ class People(cvb.BasePeople):
         '''
 
         # Handle inputs
+        inds         = inds[self.susceptible[inds]] # Do not infect people who are not susceptible
         n_infections = len(inds)
         durpars      = self.pars['dur']
 
         # Set states
-        self.susceptible[inds]    = False
-        self.exposed[inds]        = True
-        self.rel_sus[inds]        = 0.0 # Not susceptible after becoming infected
-        self.date_exposed[inds]   = self.t
-
-        # Deal with bed constraint if applicable
-        if bed_max is None: bed_max = False
+        self.susceptible[inds]   = False
+        self.exposed[inds]       = True
+        self.rel_sus[inds]       = 0.0 # Not susceptible after becoming infected
+        self.date_exposed[inds]  = self.t
 
         # Calculate how long before this person can infect other people
         self.dur_exp2inf[inds]     = cvu.sample(**durpars['exp2inf'], size=n_infections)
         self.date_infectious[inds] = self.dur_exp2inf[inds] + self.t
 
         # Use prognosis probabilities to determine what happens to them
-        is_symp = cvu.binomial_arr(self.symp_prob[inds]) # Determine if they develop symptoms
+        symp_probs = self.pars['rel_symp_prob']*self.symp_prob[inds] # Calculate their actual probability of being symptomatic
+        is_symp = cvu.binomial_arr(symp_probs) # Determine if they develop symptoms
         symp_inds = inds[is_symp]
         asymp_inds = inds[~is_symp] # Asymptomatic
 
@@ -302,7 +308,8 @@ class People(cvb.BasePeople):
         n_symp_inds = len(symp_inds)
         self.dur_inf2sym[symp_inds] = cvu.sample(**durpars['inf2sym'], size=n_symp_inds) # Store how long this person took to develop symptoms
         self.date_symptomatic[symp_inds] = self.date_infectious[symp_inds] + self.dur_inf2sym[symp_inds] # Date they become symptomatic
-        is_sev = cvu.binomial_arr(self.severe_prob[symp_inds]) # See if they're a severe or mild case
+        sev_probs = self.pars['rel_severe_prob'] * self.severe_prob[symp_inds] # Probability of these people being severe
+        is_sev = cvu.binomial_arr(sev_probs) # See if they're a severe or mild case
         sev_inds = symp_inds[is_sev]
         mild_inds = symp_inds[~is_sev] # Not severe
 
@@ -314,7 +321,8 @@ class People(cvb.BasePeople):
         # CASE 2.2: Severe cases: hospitalization required, may become critical
         self.dur_sym2sev[sev_inds] = cvu.sample(**durpars['sym2sev'], size=len(sev_inds)) # Store how long this person took to develop severe symptoms
         self.date_severe[sev_inds] = self.date_symptomatic[sev_inds] + self.dur_sym2sev[sev_inds]  # Date symptoms become severe
-        is_crit = cvu.binomial_arr(self.crit_prob[sev_inds])  # See if they're a critical case
+        crit_probs = self.pars['rel_crit_prob'] * self.crit_prob[sev_inds] # Probability of these people being critical
+        is_crit = cvu.binomial_arr(crit_probs)  # See if they're a critical case
         crit_inds = sev_inds[is_crit]
         non_crit_inds = sev_inds[~is_crit]
 
@@ -326,8 +334,8 @@ class People(cvb.BasePeople):
         # CASE 2.2.2: Critical cases: ICU required, may die
         self.dur_sev2crit[crit_inds] = cvu.sample(**durpars['sev2crit'], size=len(crit_inds))
         self.date_critical[crit_inds] = self.date_severe[crit_inds] + self.dur_sev2crit[crit_inds]  # Date they become critical
-        this_death_prob = self.death_prob[crit_inds] * (self.pars['OR_no_treat'] if bed_max else 1.) # Probability they'll die
-        is_dead = cvu.binomial_arr(this_death_prob)  # Death outcome
+        death_probs = self.pars['rel_death_prob'] * self.death_prob[crit_inds] * (self.pars['OR_no_treat'] if bed_max else 1.) # Probability they'll die
+        is_dead = cvu.binomial_arr(death_probs)  # Death outcome
         dead_inds = crit_inds[is_dead]
         alive_inds = crit_inds[~is_dead]
 
