@@ -210,7 +210,7 @@ class Scenarios(cvb.ParsObj):
         Plot the results -- can supply arguments for both the figure and the plots.
 
         Args:
-            to_plot     (dict): Dict of results to plot; see default_scen_plots for structure
+            to_plot     (dict): Dict of results to plot; see get_scen_plots() for structure
             do_save     (bool): Whether or not to save the figure
             fig_path    (str):  Path to save the figure
             fig_args    (dict): Dictionary of kwargs to be passed to pl.figure()
@@ -239,7 +239,7 @@ class Scenarios(cvb.ParsObj):
         sc.printv('Plotting...', 1, verbose)
 
         if to_plot is None:
-            to_plot = cvd.default_scen_plots
+            to_plot = cvd.get_scen_plots()
         to_plot = sc.dcp(to_plot) # In case it's supplied as a dict
 
         # Handle input arguments -- merge user input with defaults
@@ -485,7 +485,7 @@ def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, keep_people=F
     if noisepar is None:
         noisepar = 'beta'
         if noisepar not in sim.pars.keys():
-            raise cvm.KeyNotFoundError(f'Noise parameter {noisepar} was not found in sim parameters')
+            raise sc.KeyNotFoundError(f'Noise parameter {noisepar} was not found in sim parameters')
 
     # Handle noise -- normally distributed fractional error
     noiseval = noise*np.random.normal()
@@ -496,7 +496,7 @@ def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, keep_people=F
     new_sim[noisepar] *= noisefactor
 
     if verbose>=1:
-        print(f'Running a simulation using {new_sim["rand_seed"]} seed and {noisefactor} noise')
+        print(f'Running a simulation using {new_sim["rand_seed"]} seed and {noisefactor} noise factor')
 
     # Handle additional arguments
     for key,val in sim_args.items():
@@ -506,7 +506,7 @@ def single_run(sim, ind=0, noise=0.0, noisepar=None, verbose=None, keep_people=F
                 print(f'Setting key {key} from {new_sim[key]} to {val}')
                 new_sim[key] = val
         else:
-            raise cvm.KeyNotFoundError(f'Could not set key {key}: not a valid parameter name')
+            raise sc.KeyNotFoundError(f'Could not set key {key}: not a valid parameter name')
 
     # Run
     new_sim.run(**run_args)
