@@ -120,6 +120,7 @@ class Sim(cvb.BaseSim):
         self.set_seed() # Reset the random seed
         self.init_results() # Create the results stucture
         self.init_people(save_pop=save_pop, load_pop=load_pop, popfile=popfile, **kwargs) # Create all the people (slow)
+        self.init_interventions()
         self.initialized = True
         return
 
@@ -149,12 +150,8 @@ class Sim(cvb.BaseSim):
         # Handle start day
         start_day = self['start_day'] # Shorten
         if start_day in [None, 0]: # Use default start day
-            start_day = dt.date(2020, 1, 1)
-        elif sc.isstring(start_day):
-            start_day = sc.readdate(start_day)
-        if isinstance(start_day,dt.datetime):
-            start_day = start_day.date()
-        self['start_day'] = start_day
+            start_day = '2020-03-01'
+        self['start_day'] = cvm.date(start_day)
 
         # Handle contacts
         contacts = self['contacts']
@@ -167,12 +164,12 @@ class Sim(cvb.BaseSim):
         quar_eff_keys   = set(self.pars['quar_eff'].keys())
         if not(beta_layer_keys == contacts_keys == quar_eff_keys):
             errormsg = f'Layer parameters beta={beta_layer_keys}, contacts={contacts_keys}, quar_eff={quar_eff_keys} have inconsistent keys'
-            raise cvm.KeyNotFoundError(errormsg)
+            raise sc.KeyNotFoundError(errormsg)
         if self.people is not None:
             pop_keys = set(self.people.contacts.keys())
             if pop_keys != beta_layer_keys:
                 errormsg = f'Please update your parameter keys {beta_layer_keys} to match population keys {pop_keys}. You may find sim.reset_layer_pars() helpful.'
-                raise cvm.KeyNotFoundError(errormsg)
+                raise sc.KeyNotFoundError(errormsg)
 
         # Handle population data
         popdata_choices = ['random', 'hybrid', 'clustered', 'synthpops']
@@ -180,7 +177,7 @@ class Sim(cvb.BaseSim):
         if choice not in popdata_choices:
             choicestr = ', '.join(popdata_choices)
             errormsg = f'Population type "{choice}" not available; choices are: {choicestr}'
-            raise cvm.KeyNotFoundError(errormsg)
+            raise sc.KeyNotFoundError(errormsg)
 
         # Handle interventions
         self['interventions'] = sc.promotetolist(self['interventions'], keepnone=False)
@@ -206,7 +203,7 @@ class Sim(cvb.BaseSim):
             output = cvb.Result(*args, **kwargs, npts=self.npts)
             return output
 
-        dcols = cvd.default_colors # Shorten default colors
+        dcols = cvd.get_colors() # Get default colors
 
         # Stock variables
         for key,label in cvd.result_stocks.items():
@@ -291,6 +288,14 @@ class Sim(cvb.BaseSim):
         return
 
 
+    def init_interventions(self):
+        ''' Initialize the interventions '''
+        # Initialize interventions
+        for intervention in self['interventions']:
+            intervention.initialize(self)
+        return
+
+
     def step(self):
         '''
         Step the simulation forward in time
@@ -429,7 +434,7 @@ class Sim(cvb.BaseSim):
                 if verbose >= 2:
                     sc.heading(string)
                 elif verbose == 1:
-                    cvm.progressbar(t+1, self.npts, label=string, newline=True)
+                    sc.progressbar(t+1, self.npts, label=string, newline=True)
 
             # Do the heavy lifting -- actually run the model!
             self.step()
@@ -654,7 +659,7 @@ class Sim(cvb.BaseSim):
         Plot the results -- can supply arguments for both the figure and the plots.
 
         Args:
-            to_plot (dict): Nested dict of results to plot; see default_sim_plots for structure
+            to_plot (dict): Nested dict of results to plot; see get_sim_plots() for structure
             do_save (bool or str): Whether or not to save the figure. If a string, save to that filename.
             fig_path (str): Path to save the figure
             fig_args (dict): Dictionary of kwargs to be passed to pl.figure()
@@ -683,7 +688,7 @@ class Sim(cvb.BaseSim):
         sc.printv('Plotting...', 1, verbose)
 
         if to_plot is None:
-            to_plot = cvd.default_sim_plots
+            to_plot = cvd.get_sim_plots()
         to_plot = sc.odict(to_plot) # In case it's supplied as a dict
 
         # Handle input arguments -- merge user input with defaults
