@@ -25,8 +25,8 @@ else:
 
 #%% The core Covasim functions -- compute the infections
 
-@nb.njit(             (nbint, nbfloat[:], nbfloat[:],     nbfloat[:], nbfloat, nbfloat))
-def compute_viral_load(t,     time_start, time_recovered, time_dead,  par1,    par2):
+@nb.njit(             (nbint, nbfloat[:], nbfloat[:],     nbfloat[:], nbfloat, nbfloat, nbfloat))
+def compute_viral_load(t,     time_start, time_recovered, time_dead,  frac_time,    load_ratio,    high_cap):
     '''
     Calculate relative transmissibility for time t. Includes time varying
     viral load, pre/asymptomatic factor, diagonsis factor, etc.
@@ -36,8 +36,9 @@ def compute_viral_load(t,     time_start, time_recovered, time_dead,  par1,    p
         time_start: (float[]) individuals' infectious date
         time_recovered: (float[]) individuals' recovered date
         time_dead: (float[]) individuals' death date
-        par1: (float) frac of time in high load
-        par2: (float) ratio for high to low viral load
+        frac_time: (float) frac of time in high load
+        load_ratio: (float) ratio for high to low viral load
+        high_cap: (float) cap on the number of days with high viral load
 
     Returns:
         load (float): viral load
@@ -48,9 +49,21 @@ def compute_viral_load(t,     time_start, time_recovered, time_dead,  par1,    p
     time_stop = np.ones(n, dtype=cvd.default_float)*time_recovered # This is needed to make a copy
     inds = ~np.isnan(time_dead)
     time_stop[inds] = time_dead[inds]
+
+    # Calculate which individuals with be high past the cap and when it should happen
+    infect_days_total = time_stop-time_start
+    trans_day = frac_time*infect_days_total
+    inds = trans_day > high_cap
+    cap_frac = high_cap/infect_days_total[inds]
+
+    # Get corrected time to switch from high to low
+    trans_point = np.ones(n,dtype=cvd.default_float)*frac_time
+    trans_point[inds] = cap_frac
+
+    # Calculate load
     load = np.ones(n, dtype=cvd.default_float) # allocate an array of ones with the correct dtype
-    early = (t-time_start)/(time_stop-time_start) < par1 # are we in the early or late phase
-    load = (par2 * early + load * ~early)/(load+par1*(par2-load)) # calculate load
+    early = (t-time_start)/infect_days_total < trans_point # are we in the early or late phase
+    load = (load_ratio * early + load * ~early)/(load+frac_time*(load_ratio-load)) # calculate load
 
     return load
 
@@ -61,7 +74,7 @@ def compute_trans_sus(rel_trans,  rel_sus,    beta_layer, viral_load, symp,
     f_asymp    =  symp + ~symp * asymp_factor # Asymptomatic factor, changes e.g. [0,1] with a factor of 0.8 to [0.8,1.0]
     f_diag     = ~diag +  diag * diag_factor # Diagnosis factor, changes e.g. [0,1] with a factor of 0.8 to [1,0.8]
     f_quar_eff = ~quar +  quar * quar_trans # Quarantine
-    rel_trans  = rel_trans * viral_load * f_quar_eff * f_asymp * f_diag * beta_layer # Recalulate transmisibility
+    rel_trans  = rel_trans * f_quar_eff * f_asymp * f_diag * beta_layer * viral_load # Recalulate transmisibility
     rel_sus    = rel_sus   * f_quar_eff # Recalulate susceptibility
     return rel_trans, rel_sus
 
@@ -127,9 +140,12 @@ def sample(dist=None, par1=None, par2=None, size=None):
     elif dist == 'normal_pos':    samples = np.abs(np.random.normal(loc=par1, scale=par2, size=size))
     elif dist == 'normal_int':    samples = np.round(np.abs(np.random.normal(loc=par1, scale=par2, size=size)))
     elif dist in ['lognormal', 'lognormal_int']:
-        mean  = np.log(par1**2 / np.sqrt(par2 + par1**2)) # Computes the mean of the underlying normal distribution
-        sigma = np.sqrt(np.log(par2/par1**2 + 1)) # Computes sigma for the underlying normal distribution
-        samples = np.random.lognormal(mean=mean, sigma=sigma, size=size)
+        if par1>0:
+            mean  = np.log(par1**2 / np.sqrt(par2 + par1**2)) # Computes the mean of the underlying normal distribution
+            sigma = np.sqrt(np.log(par2/par1**2 + 1)) # Computes sigma for the underlying normal distribution
+            samples = np.random.lognormal(mean=mean, sigma=sigma, size=size)
+        else:
+            samples = np.zeros(size)
         if dist == 'lognormal_int': samples = np.round(samples)
     elif dist == 'neg_binomial':  samples = np.random.negative_binomial(n=par1, p=par2, size=size)
     else:
@@ -297,4 +313,4 @@ def ifalsei(arr, inds):
 
 def idefinedi(arr, inds):
     ''' Returns the indices that are defined in the array -- name is short for indices[defined[indices]] '''
-    return inds[~np.isnan(arr[inds])]
\ No newline at end of file
+    return inds[~np.isnan(arr[inds])]
